@@ -33,7 +33,7 @@ def doc2vec_concat(pretrained_emb, emb_size, context):
 
 def doc2vec_hier(pretrained_emb, emb_size, context, windows):
     arr_list = []
-    for i in list_in_windows(context, windows):
+    for i in sliding_windows(context, windows):
         try:
             arr_list.append(doc2vec_aver(pretrained_emb, emb_size, i))
         except Exception as e:
@@ -47,6 +47,6 @@ def dot(A, B):
 
 
 def cosine_similarity(vector1, vector2):
-    if vector1 is 0 or vector2 is 0:
+    if vector1 == 0 or vector2 == 0:
         return 0
     return dot(vector1, vector2) / ((dot(vector1, vector1) ** .5) * (dot(vector2, vector2) ** .5))
